### Sample View

This serves as an example of the patterns used to design views in this repo.  

Goals are for each view to be decoupled, documented, and well tested.  There is a dependency on the main package, but no other sibling packages.

Design:
![Alt Text](resources/Segmenter%20ML%20pub-sub.drawio.png)